@@ -147,7 +147,9 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             self.fit(X, symmetric=symmetric)
         return self.get_ICL()
 
-    def get_params(self, _=True):  # pylint: disable=missing-function-docstring
+    def get_params(
+        self, deep=True
+    ):  # pylint: disable=missing-function-docstring,unused-argument
         return {
             "max_iter": self.max_iter,
             "n_init": self.n_init,
